@@ -1,6 +1,5 @@
 package Bio::DB::SeqFeature::Store::LoadHelper;
 
-
 =head1 NAME
 
 Bio::DB::SeqFeature::Store::LoadHelper -- Internal utility for Bio::DB::SeqFeature::Store
@@ -41,6 +40,10 @@ use File::Temp 'tempdir';
 use File::Spec;
 use Fcntl qw(O_CREAT O_RDWR);
 
+our $VERSION = '1.10';
+
+my %DBHandles;
+
 sub new {
     my $class   = shift;
     my $tmpdir  = shift;
@@ -64,26 +67,32 @@ sub create_dbs {
     my $self = shift;
     my $tmp  = shift;
     my %self;
-
+    # experiment with caching these handles in memory
     my $hash_options           = DB_File::HASHINFO->new();
-
     # Each of these hashes allow only unique keys
     for my $dbname (qw(IndexIt TopLevel Local2Global)) {
-	my %h;
-	tie(%h,'DB_File',File::Spec->catfile($tmp,$dbname),
-	    O_CREAT|O_RDWR,0666,$hash_options);
-	$self{$dbname} = \%h;
+	unless ($DBHandles{$dbname}) {
+	    my %h;
+	    tie(%h,'DB_File',File::Spec->catfile($tmp,$dbname),
+		O_CREAT|O_RDWR,0666,$hash_options);
+	    $DBHandles{$dbname} = \%h;
+	}
+	$self{$dbname} = $DBHandles{$dbname};
+	%{$self{$dbname}} = ();
     }
 
     # The Parent2Child hash allows duplicate keys, so we
     # create it with the R_DUP flag.
     my $btree_options           = DB_File::BTREEINFO->new();
     $btree_options->{flags}     = R_DUP;
-    my %h;
-    tie(%h,'DB_File',File::Spec->catfile($tmp,'Parent2Child'),
-	O_CREAT|O_RDWR,0666,$btree_options);
-    $self{Parent2Child} = \%h;
-
+    unless ($DBHandles{'Parent2Child'}) {
+	my %h;
+	tie(%h,'DB_File',File::Spec->catfile($tmp,'Parent2Child'),
+	    O_CREAT|O_RDWR,0666,$btree_options);
+	$DBHandles{'Parent2Child'} = \%h;
+    }
+    $self{Parent2Child}    = $DBHandles{'Parent2Child'};
+    %{$self{Parent2Child}} = ();
     return \%self;
 }
 
