@@ -22,15 +22,15 @@ Bio::Taxon - A node in a represented taxonomy
   # Typically you will get a Taxon from a Bio::DB::Taxonomy object
   # but here is how you initialize one
   my $taxon = Bio::Taxon->new(-name      => $name,
-                             -id        => $id,
-                             -rank      => $rank,
-                             -division  => $div);
+                              -id        => $id,
+                              -rank      => $rank,
+                              -division  => $div);
 
   # Get one from a database
   my $dbh = Bio::DB::Taxonomy->new(-source   => 'flatfile',
-                                  -directory=> '/tmp',
-                                  -nodesfile=> '/path/to/nodes.dmp',
-                                  -namesfile=> '/path/to/names.dmp');
+                                   -directory=> '/tmp',
+                                   -nodesfile=> '/path/to/nodes.dmp',
+                                   -namesfile=> '/path/to/names.dmp');
   my $human = $dbh->get_taxon(-name => 'Homo sapiens');
   $human = $dbh->get_taxon(-taxonid => '9606');
 
@@ -45,7 +45,7 @@ Bio::Taxon - A node in a represented taxonomy
   my @ranks = qw(superkingdom class genus species);
   my @h_lineage = ('Eukaryota', 'Mammalia', 'Homo', 'Homo sapiens');
   my $list_dbh = Bio::DB::Taxonomy->new(-source => 'list', -names => \@h_lineage,
-                                                          -ranks => \@ranks);
+                                                           -ranks => \@ranks);
   $human = $list_dbh->get_taxon(-name => 'Homo sapiens');
   my @names = $human->common_names; # @names is empty
   $human->common_names('woman');
@@ -72,6 +72,7 @@ Bio::Taxon - A node in a represented taxonomy
   use Bio::Tree::Tree;
   my $tree_functions = Bio::Tree::Tree->new();
   my @lineage = $tree_functions->get_lineage_nodes($human);
+  my $lineage = $tree_functions->get_lineage_string($human);
   my $lca = $tree_functions->get_lca($human, $mouse);
 
   # b) for other methods, create a tree using your Taxon object
@@ -146,6 +147,7 @@ Internal methods are usually preceded with a _
 
 =cut
 
+
 package Bio::Taxon;
 use strict;
 use Scalar::Util qw(blessed);
@@ -154,6 +156,7 @@ use Bio::DB::Taxonomy;
 
 use base qw(Bio::Tree::Node Bio::IdentifiableI);
 
+
 =head2 new
 
  Title   : new
@@ -234,6 +237,7 @@ sub new {
     return $self;
 }
 
+
 =head1 Bio::IdentifiableI interface 
 
 Also see L<Bio::IdentifiableI>
@@ -253,6 +257,7 @@ sub version {
     return $self->{'version'};
 }
 
+
 =head2 authority
 
  Title   : authority
@@ -268,6 +273,7 @@ sub authority {
     return $self->{'authority'};
 }
 
+
 =head2 namespace
 
  Title   : namespace
@@ -283,6 +289,7 @@ sub namespace {
     return $self->{'namespace'};
 }
 
+
 =head1 Bio::Taxonomy::Node implementation
 
 =head2 db_handle
@@ -317,6 +324,7 @@ sub db_handle {
     return $self->{'db_handle'};
 }
 
+
 =head2 rank
 
  Title   : rank
@@ -333,6 +341,7 @@ sub rank {
     return $self->{'rank'};
 }
 
+
 =head2 id
 
  Title   : id
@@ -351,6 +360,7 @@ sub id {
 
 *object_id = \&id;
 
+
 =head2 ncbi_taxid
 
  Title   : ncbi_taxid
@@ -377,6 +387,7 @@ sub ncbi_taxid {
     return;
 }
 
+
 =head2 parent_id
 
  Title   : parent_id
@@ -400,6 +411,7 @@ sub parent_id {
 
 *parent_taxon_id = \&parent_id;
 
+
 =head2 genetic_code
 
  Title   : genetic_code
@@ -416,6 +428,7 @@ sub genetic_code {
     return $self->{'genetic_code'};
 }
 
+
 =head2 mitochondrial_genetic_code
 
  Title   : mitochondrial_genetic_code
@@ -432,6 +445,7 @@ sub mitochondrial_genetic_code {
     return $self->{'mitochondrial_genetic_code'};
 }
 
+
 =head2 create_date
 
  Title   : create_date
@@ -448,6 +462,7 @@ sub create_date {
     return $self->{'create_date'};
 }
 
+
 =head2 update_date
 
  Title   : update_date
@@ -464,6 +479,7 @@ sub update_date {
     return $self->{'update_date'};
 }
 
+
 =head2 pub_date
 
  Title   : pub_date
@@ -480,6 +496,7 @@ sub pub_date {
     return $self->{'pub_date'};
 }
 
+
 =head2 ancestor
 
  Title   : ancestor
@@ -513,6 +530,7 @@ sub ancestor {
     return $dbh->ancestor($definitely_from_dbh);
 }
 
+
 =head2 get_Parent_Node
 
  Title   : get_Parent_Node
@@ -527,6 +545,7 @@ sub get_Parent_Node {
     return $self->ancestor(@_);
 }
 
+
 =head2 each_Descendent
 
  Title   : each_Descendent
@@ -550,6 +569,7 @@ sub get_Parent_Node {
 
 =cut
 
+
 # implemented by Bio::Tree::Node
 
 =head2 get_Children_Nodes
@@ -566,6 +586,7 @@ sub get_Children_Nodes {
     return $self->each_Descendent(@_);
 }
 
+
 =head2 name
 
   Title:    name
@@ -581,7 +602,7 @@ sub get_Children_Nodes {
                 scientific name and common name, respectively. 'scientific' and
                 'division' are treated specially, allowing only the first value
                 in the Arg2 list to be set.
-            Arg2 .. => list of names
+            Arg2 ... => list of names
 
 =cut
 
@@ -599,6 +620,7 @@ sub name {
     return $self->{'_names_hash'}->{$name_class} || return;
 }
 
+
 =head2 node_name
 
  Title   : node_name
@@ -619,6 +641,7 @@ sub node_name {
 
 *scientific_name = \&node_name;
 
+
 =head2 common_names
 
  Title   : common_names
@@ -639,6 +662,7 @@ sub common_names {
 
 *common_name = \&common_names;
 
+
 =head2 division
 
  Title   : division
@@ -656,6 +680,7 @@ sub division {
     return pop @v;
 }
 
+
 # get a node from the database that is like the supplied node
 sub _get_similar_taxon_from_db {
     #*** not really happy with this having to be called so much; there must be
@@ -685,6 +710,7 @@ sub _get_similar_taxon_from_db {
     return $db_taxon;
 }
 
+
 # merge data from supplied Taxon into self
 sub _merge_taxa {
     my ($self, $taxon) = @_;
@@ -716,6 +742,7 @@ sub _merge_taxa {
     #*** haven't merged the other things in names() hash, could do above much easier with direct access to object data
 }
 
+
 =head2 remove_Descendent
 
  Title   : remove_Descendent
@@ -745,4 +772,5 @@ sub remove_Descendent {
     return $c;
 }
 
+
 1;
